@@ -4,13 +4,13 @@ from trytond.model import fields
 from trytond.pyson import Eval, Bool, Id
 from trytond.pool import PoolMeta, Pool
 
-__all__ = ['Template']
-__metaclass__ = PoolMeta
+__all__ = ['Template', 'Product']
 
 NON_MEASURABLE = ['service']
 
 
 class Template:
+    __metaclass__ = PoolMeta
     __name__ = 'product.template'
 
     length = fields.Float('Length',
@@ -170,3 +170,8 @@ class Template:
             ('//page[@id="measurements"]', 'states', {
                     'invisible': Eval('type').in_(NON_MEASURABLE),
                     })]
+
+
+class Product:
+    __metaclass__ = PoolMeta
+    __name__ = 'product.product'
